/*******************************************************************************
 *
 * buffer.h 
 *                   
 * Provides a data structure as well as supporting functions for loading 
 * a source file into memory and parsing it. 
 * 
 * Cheetah Web Browser
 * Copyright (C) 2001 Garett Spencley 
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. 
 *
 *******************************************************************************/

#ifndef __BUFFER_H__
#define __BUFFER_H__

#include <stdlib.h>

typedef struct {
	char **lines;
	int num_lines;
	int line_counter;
	int char_counter;
	int size;
} buffer_t;


buffer_t *create_empty_buffer();
void dispose_buffer(buffer_t *buffer);

buffer_t *buffer_load_file(char *file);
buffer_t *http_get_document(char *host, char *doc);

void buffer_get_line(buffer_t *buf, char *dst, size_t n);

int buffer_add_line(buffer_t *buf, const char *line);
int buffer_get_char(buffer_t *buf);
void buffer_unget_char(int c, buffer_t *buf);

#ifdef _DEBUG
void print_buffer(buffer_t *buf);
#else
inline static void print_buffer(buffer_t *buf) {}
#endif

#endif
