/*******************************************************************************
 *
 * toolbar.c - Creates the toolbar.
 *
 * Cheetah Web Browser
 * Copyright (C) 2001 Garett Spencley 
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. 
 *
 *******************************************************************************/

#include "toolbar.h"
#include "gui.h"

#include "back.xpm"
#include "forward.xpm"
#include "reload.xpm"
#include "stop.xpm"

void toolbar_add_icon(GtkWidget *toolbar, gchar **xpm, 
				char *text, GtkSignalFunc callback);

/*
 * toolbar_add_item()
 *
 * appends an item to a toolbar.
 */

__inline void toolbar_add_xpm(GtkWidget *toolbar, gchar **xpm, 
				char *text, GtkSignalFunc callback)
{
	GdkPixmap *icon;
	GtkWidget *iconw;
	GdkBitmap *mask;

	icon = gdk_pixmap_create_from_xpm_d(window->window, &mask, 
					&window->style->white, xpm); 

	iconw = gtk_pixmap_new(icon, mask); 

	gtk_toolbar_append_item(GTK_TOOLBAR(toolbar), text, text, "Private", 
					iconw, callback, NULL);

	return;
}

/*
 * init_toolbar()
 *
 * creates the toolbar.
 * Returns pointer to a handlebox containing the
 * toolbar.
 */

int init_toolbar(GtkWidget *box)
{
	GtkWidget *toolbar;

	toolbar = gtk_toolbar_new(GTK_ORIENTATION_HORIZONTAL,
							GTK_TOOLBAR_BOTH);

	gtk_toolbar_set_space_size(GTK_TOOLBAR(toolbar), 5);

	gtk_box_pack_start(GTK_BOX(box), toolbar, FALSE, TRUE, 0);

	toolbar_add_xpm(toolbar, (gchar **)back_xpm, "Back", 
				NULL); //GTK_SIGNAL_FUNC(new_document));
	
	gtk_toolbar_append_space(GTK_TOOLBAR(toolbar)); 

	toolbar_add_xpm(toolbar, (gchar **)forward_xpm, "Forward", 
				NULL); // GTK_SIGNAL_FUNC(open_document));
	
	gtk_toolbar_append_space(GTK_TOOLBAR(toolbar)); 

	toolbar_add_xpm(toolbar, (gchar **)reload_xpm, "Reload", 
				NULL); //GTK_SIGNAL_FUNC(save_document));

	gtk_toolbar_append_space(GTK_TOOLBAR(toolbar)); 

	toolbar_add_xpm(toolbar, (gchar **)stop_xpm, "Stop", 
				NULL); //GTK_SIGNAL_FUNC(save_document_as));

	gtk_toolbar_append_space(GTK_TOOLBAR(toolbar)); 
	gtk_toolbar_append_space(GTK_TOOLBAR(toolbar)); 

	gtk_widget_show(toolbar);

	return 0;
}
